# Subete

Subete is a Python library for interacting with the Sample Programs
repository. It works by cloning the repository and analyzing its
contents. It is currently in its alpha form, but you can already
see it being used in various Sample Programs projects. 

If you're interested in exploring the repo programatically,
check out the [official documentation](https://subete.jeremygrifski.com). 
